package com.ruoyi.dz.mapper;

import java.util.Collection;
import java.util.List;
import com.ruoyi.dz.domain.DzAgent;
import org.apache.ibatis.annotations.Param;

/**
 * 机构代理Mapper接口
 *
 * @author ruoyi
 * @date 2025-09-12
 */
public interface DzAgentMapper
{
    public List<DzAgent> selectDzAgentByAgentIds(@Param("ids")Collection<Long> ids);

    /**
     * 查询机构代理
     *
     * @param agentId 机构代理主键
     * @return 机构代理
     */
    public DzAgent selectDzAgentByAgentId(Long agentId);
    public DzAgent selectDzAgentByUserId(Long userId);
    public List<DzAgent> selectDzAgentByUserIds(@Param("userIds") Collection<Long> userIds);

    /**
     * 查询机构代理列表
     *
     * @param dzAgent 机构代理
     * @return 机构代理集合
     */
    public List<DzAgent> selectDzAgentList(DzAgent dzAgent);

    /**
     * 新增机构代理
     *
     * @param dzAgent 机构代理
     * @return 结果
     */
    public int insertDzAgent(DzAgent dzAgent);

    /**
     * 修改机构代理
     *
     * @param dzAgent 机构代理
     * @return 结果
     */
    public int updateDzAgent(DzAgent dzAgent);

    /**
     * 删除机构代理
     *
     * @param agentId 机构代理主键
     * @return 结果
     */
    public int deleteDzAgentByAgentId(Long agentId);

    /**
     * 批量删除机构代理
     *
     * @param agentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDzAgentByAgentIds(Long[] agentIds);
}
